AndThen

Struct AndThen 

pub struct AndThen<S, T, F>(/* private fields */);
Run a decoder and use the produced item to construct the next decoder to run.

Implementations

Source

impl<S, T, F> AndThen<S, T, F>

pub fn new(first: S, f: F) -> AndThen<S, T, F>

Run a decoder and use the produced item to construct the next decoder to run.